@@ -8,7 +8,7 @@ use Curses;
 
 @ISA = qw(Exporter Paw_base);
 @EXPORT = qw();
-$Paw::VERSION = "0.41";
+$Paw::VERSION = "0.45";
 
 =head1 Line Widget
 
@@ -29,6 +29,32 @@ B<Example>
 
      $l=Paw::Paw_line->new(length=>$columns, char=>"#");
 
+=head2 abs_move_widget($new_x, $new_y)
+
+the widget moves to the new absolute screen position.
+if you set only one of the two parameters, the other one keeps the old value.
+
+B<Example>
+
+     $l->abs_move_widget( new_x=>5 );      #y-pos is the same
+
+=head2 get_widget_pos()
+
+returns an array of two values, the x-position and the y-position of the widget.
+
+B<Example>
+
+     ($xpos,$ypos)=$l->get_widget_pos();      #y-pos is the same
+
+=head2 set_color($color_pair)
+
+Set a new color_pair for the widget.
+
+B<Example>
+
+     $box->set_color(3);
+
+
 =cut
 
 sub new {
